@@ -1,7 +1,7 @@
 from django.contrib.admin.widgets import ForeignKeyRawIdWidget
 from django.urls import reverse
 from django.utils.safestring import mark_safe
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 
 class CantoImageWidget(ForeignKeyRawIdWidget):
